package com.incubator.game.handler.club;

import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.incubator.common.MessageHandler;
import com.incubator.common.net.Connection;
import com.incubator.core.net.ws.NetHandler;
import com.incubator.core.net.ws.WSRequest;
import com.incubator.core.net.ws.WSResponse;
import com.incubator.game.constant.RedisKeyConstant;
import com.incubator.game.data.jedis.RedisUtil;
import com.incubator.game.data.po.ZjClubPo;
import com.incubator.game.data.po.ZjUserLobbyPo;
import com.incubator.game.util.UtilCore;
import com.incubator.message.proto.CommonProto;

import java.util.List;

/**
 * Author:  xhb
 * Date:  2024-12-09 14:27
 * 创建俱乐部
 */
@MessageHandler(id = CommonProto.Cmd.CreateClubReq_VALUE)
public class CreateClub extends NetHandler {

    @Override
    public void onDate(Connection session, WSRequest request, WSResponse response) {
        response.setCmd(CommonProto.Cmd.CreateClubRes_VALUE);

        String userId = request.getDataValue("userId", String.class, "");
        String clubInfo = request.getDataValue("clubInfo", String.class, "");

        try {
            JSONObject jsonObject = getClubListFromRedis();
            JSONArray clubArray = jsonObject.getJSONArray("clubList");
            List<ZjClubPo> clubList = clubArray.toList(ZjClubPo.class);

            if (isUserAlreadyCreatedClub(clubList, userId)) {
                response.setCode(CommonProto.Code.PARAMETER_ERR_VALUE);
                response.setMessage("您已创建过俱乐部");
                return;
            }

            ZjClubPo newClub = createNewClub(clubInfo, userId);
            addClubToRedis(jsonObject, clubArray, newClub);

            updateUserLobbyClub(jsonObject, userId, newClub);
        } catch (Exception e) {
            // 处理异常，例如记录日志或返回错误响应
            response.setCode(CommonProto.Code.SYSTEM_ERR_VALUE);
            response.setMessage("创建俱乐部时发生错误");
            e.printStackTrace();
        }
    }
    private JSONObject getClubListFromRedis() {
        String clubListStr = RedisUtil.get(RedisKeyConstant.CLUB_BASE);
        return JSONUtil.parseObj(clubListStr);
    }

    private boolean isUserAlreadyCreatedClub(List<ZjClubPo> clubList, String userId) {
        return clubList.stream().anyMatch(club -> club.getClubCreator().equals(userId));
    }

    private ZjClubPo createNewClub(String clubInfo, String userId) {
        ZjClubPo newClub = JSONUtil.parseObj(clubInfo).toBean(ZjClubPo.class);
        newClub.setClubId(UtilCore.getDateRandomId());
        newClub.setClubCreator(userId);
        newClub.setOnlineCount(1);
        newClub.setClubStatus("1");
        newClub.setClubLevel(1);
        return newClub;
    }

    private void addClubToRedis(JSONObject jsonObject, JSONArray clubArray, ZjClubPo newClub) {
        clubArray.add(newClub);
        jsonObject.set("clubList", clubArray);
        RedisUtil.set(RedisKeyConstant.CLUB_BASE, jsonObject.toString());
    }

    private void updateUserLobbyClub(JSONObject userObject, String userId, ZjClubPo newClub) {
        String userInfo = RedisUtil.get(RedisKeyConstant.USER_BASE + userId);
        userObject = JSONUtil.parseObj(userInfo);
        Object lobbyUserObj = userObject.get("lobbyUser");
        ZjUserLobbyPo lobbyUser = JSONUtil.toBean((JSONObject) lobbyUserObj, ZjUserLobbyPo.class);
        lobbyUser.setUserClub(newClub.getClubId());
        userObject.put("lobbyUser", lobbyUser);
        RedisUtil.set(RedisKeyConstant.USER_BASE + userId, userObject.toString());
    }
}
