package com.incubator.game.handler.club;

import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import cn.hutool.jwt.JWT;
import cn.hutool.jwt.JWTUtil;
import com.incubator.common.MessageHandler;
import com.incubator.common.net.Connection;
import com.incubator.core.net.ws.NetHandler;
import com.incubator.core.net.ws.WSRequest;
import com.incubator.core.net.ws.WSResponse;
import com.incubator.game.constant.RedisKeyConstant;
import com.incubator.game.data.jedis.RedisUtil;
import com.incubator.game.data.po.ZjClubPo;
import com.incubator.message.proto.CommonProto;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Author:  xhb
 * Date:  2024-12-09 13:19
 * 获取俱乐部列表信息
 */
@MessageHandler(id = CommonProto.Cmd.ClubInfoReq_VALUE)
public class GetClubListHandler extends NetHandler {


    @Override
    public void onDate(Connection session, WSRequest request, WSResponse response) {
        response.setCmd(CommonProto.Cmd.ClubInfoRes_VALUE);

        //校验token
        String token = request.getDataValue("token", String.class, "");
        if (token == null) {
            response.setCode(CommonProto.Code.SYSTEM_ERR_VALUE);
            response.setMessage("非法请求/token不存在/token为空");
            return;
        }
        //取出俱乐部列表
        String clubs = RedisUtil.get(RedisKeyConstant.CLUB_BASE);
        JSONObject jsonObject = JSONUtil.parseObj(clubs);
        // 从JSONObject中获取包含俱乐部列表的数组
        JSONArray clubArray = jsonObject.getJSONArray("clubList");
        // 将JSONArray转换为List<ClubDto>
        List<ZjClubPo> clubList = clubArray.toList(ZjClubPo.class);
        Map<String, Object> map = new HashMap<>();
        map.put("clubList", clubList);
        response.setData(map);
    }
}
