package com.incubator.game.handler.club;

import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import cn.hutool.jwt.JWT;
import cn.hutool.jwt.JWTUtil;
import com.incubator.common.MessageHandler;
import com.incubator.common.net.Connection;
import com.incubator.core.net.ws.NetHandler;
import com.incubator.core.net.ws.WSRequest;
import com.incubator.core.net.ws.WSResponse;
import com.incubator.game.constant.RedisKeyConstant;
import com.incubator.game.data.jedis.RedisUtil;
import com.incubator.game.data.po.ZjClubPo;
import com.incubator.game.data.po.ZjUserLobbyPo;
import com.incubator.message.proto.CommonProto;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Author:  xhb
 * Date:  2024-12-09 13:38
 * 获取我的俱乐部信息
 */
@MessageHandler(id = CommonProto.Cmd.MyClubReq_VALUE)
public class GetMyClub extends NetHandler {


    @Override
    public void onDate(Connection session, WSRequest request, WSResponse response) {
        response.setCmd(CommonProto.Cmd.MyClubRes_VALUE);

        //校验token
        String token = request.getDataValue("token", String.class, "");
        if (token == null) {
            response.setCode(CommonProto.Code.SYSTEM_ERR_VALUE);
            response.setMessage("非法请求/token不存在/token为空");
            return;
        }
        String userId = request.getDataValue("userId", String.class, "");
        String userInfo = RedisUtil.get(RedisKeyConstant.USER_BASE + userId);
        JSONObject userObject = JSONUtil.parseObj(userInfo);
        Object lobbyUserObj = userObject.get("lobbyUser");
        ZjUserLobbyPo lobbyUser = JSONUtil.toBean((JSONObject) lobbyUserObj, ZjUserLobbyPo.class);
        if (lobbyUser.getUserClub() == null||lobbyUser.getUserClub().equals("")) {
            response.setCode(CommonProto.Code.SYSTEM_ERR_VALUE);
            response.setMessage("您当前未加入俱乐部");
            return;
        }
        // 根据token获取用户信息
        String club = RedisUtil.get(RedisKeyConstant.CLUB_MEMBER + lobbyUser.getUserClub());
        JSONObject clubObject = JSONUtil.parseObj(club);
        // 从JSONObject中获取包含俱乐部列表的数组
        JSONArray clubArray = clubObject.getJSONArray("clubMember");
        // 将JSONArray转换为List<ClubDto>
        List<ZjClubPo> clubMemberList = clubArray.toList(ZjClubPo.class);
        Map<String, Object> map = new HashMap<>();
        map.put("clubMemberList", clubMemberList);
        response.setData(map);
    }
}
