package com.incubator.game.handler.club;

import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.incubator.common.MessageHandler;
import com.incubator.common.net.Connection;
import com.incubator.core.net.ws.NetHandler;
import com.incubator.core.net.ws.WSRequest;
import com.incubator.core.net.ws.WSResponse;
import com.incubator.game.constant.RedisKeyConstant;
import com.incubator.game.data.jedis.RedisUtil;
import com.incubator.game.data.po.ZjClubPo;
import com.incubator.game.data.po.ZjUserLobbyPo;
import com.incubator.message.proto.CommonProto;

import java.util.Date;
import java.util.List;
import java.util.Random;

/**
 * Author:  xhb
 * Date:  2024-12-09 14:27
 */
@MessageHandler(id = CommonProto.Cmd.QuitClubReq_VALUE)
public class QuitClub extends NetHandler {

    @Override
    public void onDate(Connection session, WSRequest request, WSResponse response) {
        response.setCmd(CommonProto.Cmd.QuitClubRes_VALUE);

        String userId = request.getDataValue("userId", String.class, "");
        String clubId = request.getDataValue("clubId", String.class, "");

        try {
            // 更新用户在俱乐部的状态
            updateClubMemberStatus(clubId, userId);

            // 更新用户的主俱乐部信息
            updateUserMainClub(userId, clubId);
        } catch (Exception e) {
            // 异常处理
            logger.error("系统异常 " + userId, e);
            response.setCmd(CommonProto.Code.SYSTEM_ERR_VALUE);
        }
    }

    private void updateClubMemberStatus(String clubId, String userId) {
        String zjClubMember = RedisUtil.get(RedisKeyConstant.CLUB_MEMBER + clubId);
        JSONArray clubArray = JSONUtil.parseObj(zjClubMember).getJSONArray("clubMember");
        List<ZjClubPo> clubMemberList = clubArray.toList(ZjClubPo.class);

        for (ZjClubPo clubPo : clubMemberList) {
            if (clubPo.getUserId().equals(userId)) {
                clubPo.setMemberStatus("3");
                clubPo.setQuitTime(new Date());
                break;
            }
        }

        JSONObject object = new JSONObject();
        object.put("clubMember", clubMemberList);
        RedisUtil.set(RedisKeyConstant.CLUB_MEMBER + clubId, object.toString());
    }

    private void updateUserMainClub(String userId, String clubId) {
        String userInfo = RedisUtil.get(RedisKeyConstant.USER_BASE + userId);
        JSONObject jsonObject = JSONUtil.parseObj(userInfo);
        ZjUserLobbyPo lobbyUser = JSONUtil.toBean(jsonObject.getJSONObject("lobbyUser"), ZjUserLobbyPo.class);

        String userClub = lobbyUser.getUserClub();
        if (userClub != null && userClub.equals(clubId)) {
            String clubListStr = RedisUtil.get(RedisKeyConstant.CLUB_BASE);
            JSONArray clubListArray = JSONUtil.parseObj(clubListStr).getJSONArray("clubList");
            List<ZjClubPo> clubList = clubListArray.toList(ZjClubPo.class);

            if (clubList.isEmpty()) {
                lobbyUser.setUserClub(null);
            } else {
                Random random = new Random();
                int randomIndex = random.nextInt(clubList.size());
                String newClubId = clubList.get(randomIndex).getClubId();
                lobbyUser.setUserClub(newClubId);
            }
        }

        JSONObject object = new JSONObject();
        object.put("lobbyUser", lobbyUser);
        RedisUtil.set(RedisKeyConstant.USER_BASE + userId, object.toString());
    }
}
