package com.incubator.game.handler.room;

import com.alibaba.fastjson2.JSONObject;
import com.incubator.common.MessageHandler;
import com.incubator.common.net.Connection;
import com.incubator.core.net.ws.NetHandler;
import com.incubator.core.net.ws.WSRequest;
import com.incubator.core.net.ws.WSResponse;
import com.incubator.game.player.Player;
import com.incubator.game.room.Room;
import com.incubator.game.room.RoomService;
import com.incubator.game.util.ProtoUtil;
import com.incubator.game.util.PlayerUtil;
import com.incubator.message.proto.CommonProto;

/**
 * 创建房间请求
 *
 * @author johnc
 */
@MessageHandler(id = CommonProto.Cmd.CreateRoomReq_VALUE)
public class CreatRoomHandler extends NetHandler {

	@Override
	public void onDate(Connection session, WSRequest request, WSResponse response) {
		response.setCmd(CommonProto.Cmd.CreateRoomRes_VALUE);

		Player player = (Player) PlayerUtil.getOnlinePlayer(session.getPlayerId());
		if (player == null) {
			logger.info("创建房间失败，找不到玩家");
			response.setCode(CommonProto.Code.SYSTEM_ERR_VALUE);
			response.setMessage("操作失败");
			return;
		}

		// 判断参数
		int[] type = request.getDataValue("type", int[].class, new int[]{});
		if (type.length != 11) {
			logger.info("参数错误");
			response.setCode(CommonProto.Code.PARAMETER_ERR_VALUE);
			response.setMessage("参数错误");
			return;
		}

		// 解析规则
		JSONObject jsonData = new JSONObject();
		jsonData.put("gameType", type[0]);
		jsonData.put("playingTypeOne", type[1]);
		jsonData.put("playingTypeTwo", type[2]);
		jsonData.put("upgradeType", type[3]);
		jsonData.put("flippingType", type[4]);
		jsonData.put("advanceType", type[5]);
		jsonData.put("timeoutType", type[6]);
		jsonData.put("voiceType", type[7]);
		jsonData.put("recordType", type[8]);
		jsonData.put("watchType", type[9]);
		jsonData.put("PlayerNum", type[10]);

		// 玩家是否存在房间
		Room room = RoomService.getInstance().getRoomByPlayerId(player.getId());
		if (room != null) {
			logger.info("玩家已在房间，不可创建房间");
			response.setCode(CommonProto.Code.PLAYER_ROOM_EXIST_ERR_VALUE);
			response.setMessage("操作失败");
			return;
		}

		// 创建房间
		room = RoomService.getInstance().creatRoom(player, jsonData.getInteger("gameType"), jsonData);

		if (room == null) {
			logger.info("系统错误");
			response.setCode(CommonProto.Code.SYSTEM_ERR_VALUE);
			response.setMessage("操作失败");
			return;
		}

		// 玩家绑定房间
		player.data.roomId = room.roomId;

		// 正常返回
		response.setData(ProtoUtil.roomToMessage(room, player, null));
	}
}
